==> phpicalendar-2.1p0.tgz: phpicalendar/languages/english.inc.php <==
<?php

// English language include
// For version 2.0 PHP iCalendar
//
// Translation by Chad Little (chad@chadsdomain.com)
//
// Submit new translations to chad@chadsdomain.com

$lang['l_day'] 				= 'Day';
$lang['l_week'] 			= 'Week';
$lang['l_month'] 			= 'Month';
$lang['l_year'] 			= 'Year';
$lang['l_calendar'] 		= 'Calendar';
$lang['l_next_day'] 		= 'Next Day';
$lang['l_next_month'] 		= 'Next Month';
$lang['l_next_week'] 		= 'Next Week';
$lang['l_next_year'] 		= 'Next Year';
$lang['l_last_day'] 		= 'Previous Day';
$lang['l_last_month'] 		= 'Previous Month';
$lang['l_last_week'] 		= 'Previous Week';
$lang['l_last_year'] 		= 'Previous Year';
$lang['l_subscribe'] 		= 'Subscribe';
$lang['l_download'] 		= 'Download';
$lang['l_powered_by'] 		= 'Powered by';
$lang['l_event'] 			= 'Event';
$lang['l_event_start'] 		= 'Start Time';
$lang['l_event_end'] 		= 'End Time';
$lang['l_this_months'] 		= 'This Month\'s Events';
$lang['l_date'] 			= 'Date';
$lang['l_summary'] 			= 'Summary';
$lang['l_all_day'] 			= 'All day event';
$lang['l_notes'] 			= 'Notes';
$lang['l_this_years'] 		= 'This Year\'s Events';
$lang['l_today'] 			= 'Today';
$lang['l_this_week'] 		= 'This Week';
$lang['l_this_month'] 		= 'This Month';
$lang['l_jump'] 			= 'Jump to';
$lang['l_tomorrows'] 		= 'Tomorrow\'s Events';
$lang['l_goday'] 			= 'Go to Today';
$lang['l_goweek'] 			= 'Go to This Week';
$lang['l_gomonth'] 			= 'Go to This Month';
$lang['l_goyear'] 			= 'Go to This Year';
$lang['l_search'] 			= 'Search'; // the verb
$lang['l_results'] 			= 'Search Results';
$lang['l_query'] 			= 'Query'; // will be followed by the search query
$lang['l_no_results'] 		= 'No events found';
$lang['l_goprint'] 			= 'Printer Friendly';
$lang['l_time'] 			= 'Time';
$lang['l_summary'] 			= 'Summary';
$lang['l_description'] 		= 'Description';
$lang['l_this_site_is']		= 'This site is';
$lang['l_no_events_day']	= 'No events today.';
$lang['l_no_events_week']	= 'No events this week.';
$lang['l_no_events_month']	= 'No events this month.';
$lang['l_rss_day_date']		= 'g:i A';  // Lists just the time
$lang['l_rss_week_date	']	= '%b %e';  // Lists just the day
$lang['l_rss_month_date	']	= '%b %e';  // Lists just the day
$lang['l_rss_language']		= 'en-us';
$lang['l_search_took']		= 'Search took %s seconds';
$lang['l_recurring_event']	= 'Recurring event';
$lang['l_exception']		= 'Exception';
$lang['l_no_query']			= 'No query given';
$lang['l_preferences']		= 'Preferences';
$lang['l_printer']			= 'Printer';
$lang['l_select_lang']		= 'Select your default language';
$lang['l_select_cal']		= 'Select your default calendar';
$lang['l_select_view']		= 'Select your default view';
$lang['l_select_time']		= 'Select your default start time';
$lang['l_select_day']		= 'Select your default start day of week';
$lang['l_select_style']		= 'Select your default style';
$lang['l_set_prefs']		= 'Set preferences';
$lang['l_completed_date']	= 'Completed on';
$lang['l_completed']		= 'Completed';
$lang['l_created']			= 'Created';
$lang['l_due']				= 'Due';
$lang['l_priority']			= 'Priority';
$lang['l_priority_high']	= 'High';
$lang['l_priority_low']		= 'Low';
$lang['l_priority_medium']	= 'Medium';
$lang['l_priority_none']	= 'None';
$lang['l_status']			= 'Status';
$lang['l_todo']				= 'To do items';
$lang['l_unfinished']		= 'Unfinished';
$lang['l_prefs_set'] 		= 'Your preferences have been set.';
$lang['l_prefs_unset'] 		= 'Preferences unset. Changes will take place next page load.';
$lang['l_unset_prefs'] 		= 'Unset preferences';
$lang['l_organizer']		= 'Organizer';
$lang['l_attendee']			= 'Attendee';
$lang['l_location']			= 'Location';
$lang['l_admin_header']		= 'PHP iCalendar Administration';
$lang['l_username']			= 'Username';
$lang['l_password']			= 'Password';
$lang['l_login']			= 'Login';
$lang['l_invalid_login']	= 'Wrong username or password.';
$lang['l_addupdate_cal']	= 'Add or Update a Calendar';
$lang['l_addupdate_desc']	= 'Add a calendar by uploading a new file. Update a calendar by uploading a file of the same name.';
$lang['l_delete_cal']		= 'Delete a Calendar';
$lang['l_logout']			= 'Logout';
$lang['l_cal_file']			= 'Calendar File';
$lang['l_php_error']		= 'PHP Error';
$upload_error_gen_lang		= 'There was a problem with your upload.';
$upload_error_lang[0]		= 'There was a problem with your upload.';
$upload_error_lang[1]		= 'The file you are trying to upload is too big.';
$upload_error_lang[2]		= 'The file you are trying to upload is too big.';
$upload_error_lang[3]		= 'The file you are trying upload was only partially uploaded.';
$upload_error_lang[4]		= 'You must select a file for upload.';
$lang['l_upload_error_type'] = 'Only .ics files may be uploaded.';
$lang['l_copy_error']			= 'Failed to copy file';
$lang['l_delete_error']			= 'Failed to delete file';
$lang['l_delete_success']		= 'was deleted successfully.';
$lang['l_action_success']		= 'Your action was successful.';
$lang['l_submit']				= 'Submit';
$lang['l_delete']				= 'Delete';
$all_cal_comb_lang			= 'All Combined';

// New for 2.0
$lang['l_legend']			= 'Legend';
$lang['l_admin_subhead']	= 'Manage your calendars from this page';
$lang['l_prefs_subhead']	= 'Sets a cookie for visiting this site';
$lang['l_rss_info']			= 'RSS Information';
$lang['l_rss_subhead']		= 'Basic RSS feeds available for each calendar';
$lang['l_rss_notenabled']	= 'RSS is not enabled on this site';

// - navigation
$lang['l_back'] 		= 'Back';
$lang['l_next'] 		= 'Next';
$lang['l_prev'] 		= 'Prev';
$lang['l_day_view'] 	= 'Day View';
$lang['l_week_view'] 	= 'Week View';
$lang['l_month_view'] 	= 'Month View';
$lang['l_year_view'] 	= 'Year View';

// ---------------------------------


// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';								// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('year','years');		// for these, put singular
$format_recur_lang['monthly']		= array('month','months');		// and plural forms
$format_recur_lang['weekly']		= array('week','weeks');		// these will be %freq%
$format_recur_lang['daily']			= array('day','days');			// in the replacement below
$format_recur_lang['hourly']		= array('hour','hours');
$format_recur_lang['minutely']		= array('minute','minutes');
$format_recur_lang['secondly']		= array('second','seconds');

$format_recur_lang['start']			= 'Every %int% %freq% %for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']			= 'until %date%';				// ie, 'until January 4'
$format_recur_lang['count']			= 'for a count of %int%';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= 'In months: %list%';			// ie, 'In months: January, February, March'
$format_recur_lang['bymonthday']	= 'On dates: %list%';			// ie, 'On dates: 1, 2, 3, 4'
$format_recur_lang['byday']			= 'On days: %list%';			// ie, 'On days: Mon, Tues, Wed, Thurs'

// ---------------------------------

$daysofweek_lang			= array ('Sunday','Monday','Tuesday','Wednesday','Thursday','Friday','Saturday');
$daysofweekshort_lang		= array ('Sun','Mon','Tue','Wed','Thu','Fri','Sat');
$daysofweekreallyshort_lang	= array ('S','M','T','W','T','F','S');
$monthsofyear_lang			= array ('January','February','March','April','May','June','July','August','September','October','November','December');
$monthsofyearshort_lang		= array ('Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec');

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
$timeFormat = 'g:i A';
$timeFormat_small = 'g:i';

// For date formatting, see note below
$dateFormat_day = '%A, %B %e';
$dateFormat_week = '%B %e';
$dateFormat_week_list = '%a, %b %e';
$dateFormat_week_jump = '%b %e';
$dateFormat_month = '%B %Y';
$dateFormat_month_list = '%A, %B %e';

/*
Notes about dateFormat_*
	The pieces are similar to that of the PHP function strftime(), 
	however only the following is supported at this time:
	
	%A - the full week day name as specified in $daysofweek_lang
	%a - the shortened week day name as specified in $daysofweekshort_lang
	%B - the full month name as specified in $monthsofyear_lang
	%b - the shortened month name as specified in $monthsofyearshort_lang
	%e - the day of the month as a decimal number (1 to 31)
	%Y - the 4-digit year

	If this causes problems with representing your language accurately, let
	us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] 			= 'Error!';
$lang['l_error_window'] 		= 'There was an error!';
$lang['l_error_calendar'] 		= 'The calendar "%s" was being processed when this error occurred.';
$lang['l_error_path'] 			= 'Unable to open the path: "%s"';
$lang['l_error_back'] 			= 'Please use the "Back" button to return.';
$lang['l_error_remotecal'] 		= 'This server blocks remote calendars which have not been approved.';
$lang['l_error_restrictedcal'] 	= 'You have tried to access a calendar that is restricted on this server.';
$lang['l_error_invalidcal'] 	= 'Invalid calendar file. Please try a different calendar.';
$lang['l_error_cantopen'] 		= 'Unable to open calendar.';
$lang['l_error_cache']			= 'Unable to write to cache directory. Please check your config.';

?>

==> phpicalendar-2.31.tgz: phpicalendar/languages/english.inc.php <==
<?php

// English language include
// For version 2.0 PHP iCalendar
//
// Translation by Chad Little (chad@chadsdomain.com)
//
// Submit new translations to phpicalendar@gmail.com

$lang['l_day'] 				= 'Day';
$lang['l_week'] 			= 'Week';
$lang['l_month'] 			= 'Month';
$lang['l_year'] 			= 'Year';
$lang['l_calendar'] 		= 'Calendar';
$lang['l_next_day'] 		= 'Next Day';
$lang['l_next_month'] 		= 'Next Month';
$lang['l_next_week'] 		= 'Next Week';
$lang['l_next_year'] 		= 'Next Year';
$lang['l_last_day'] 		= 'Previous Day';
$lang['l_last_month'] 		= 'Previous Month';
$lang['l_last_week'] 		= 'Previous Week';
$lang['l_last_year'] 		= 'Previous Year';
$lang['l_subscribe'] 		= 'Subscribe';
$lang['l_download'] 		= 'Download';
$lang['l_powered_by'] 		= 'Powered by';
$lang['l_event'] 			= 'Event';
$lang['l_event_start'] 		= 'Start Time';
$lang['l_event_end'] 		= 'End Time';
$lang['l_this_months'] 		= 'This Month\'s Events';
$lang['l_date'] 			= 'Date';
$lang['l_summary'] 			= 'Summary';
$lang['l_all_day'] 			= 'All day event';
$lang['l_notes'] 			= 'Notes';
$lang['l_this_years'] 		= 'This Year\'s Events';
$lang['l_today'] 			= 'Today';
$lang['l_this_week'] 		= 'This Week';
$lang['l_this_month'] 		= 'This Month';
$lang['l_jump'] 			= 'Jump to';
$lang['l_todays']    		= 'Today\'s Events';
$lang['l_tomorrows'] 		= 'Tomorrow\'s Events';
$lang['l_goday'] 			= 'Go to Today';
$lang['l_goweek'] 			= 'Go to This Week';
$lang['l_gomonth'] 			= 'Go to This Month';
$lang['l_goyear'] 			= 'Go to This Year';
$lang['l_search'] 			= 'Search'; // the verb
$lang['l_results'] 			= 'Search Results';
$lang['l_pick_multiple'] 	= 'Pick multiple';
$lang['l_query'] 			= 'Query'; // will be followed by the search query
$lang['l_no_results'] 		= 'No events found';
$lang['l_goprint'] 			= 'Printer Friendly';
$lang['l_view_calendars']	= 'Calendar view';
$lang['l_time'] 			= 'Time';
$lang['l_summary'] 			= 'Summary';
$lang['l_description'] 		= 'Description';
$lang['l_this_site_is']		= 'This site is';
$lang['l_no_events_day']	= 'No events today.';
$lang['l_no_events_week']	= 'No events this week.';
$lang['l_no_events_month']	= 'No events this month.';
$lang['l_rss_day_date']		= 'g:i A';  // Lists just the time
$lang['l_rss_week_date	']	= '%b %e';  // Lists just the day
$lang['l_rss_month_date	']	= '%b %e';  // Lists just the day
$lang['l_rss_language']		= 'en-us';
$lang['l_search_took']		= 'Search took %s seconds';
$lang['l_starting_on']  	= 'Starting on ';
$lang['l_recurring_event']	= 'Recurring event';
$lang['l_exception']		= 'Exception';
$lang['l_no_query']			= 'No query given';
$lang['l_preferences']		= 'Preferences';
$lang['l_printer']			= 'Printer';
$lang['l_select_lang']		= 'Select your default language';
$lang['l_select_cal']		= 'Select your default calendar';
$lang['l_select_view']		= 'Select your default view';
$lang['l_select_time']		= 'Select your default start time';
$lang['l_select_timezone']	= 'Select your default timezone';
$lang['l_select_endtime']	= 'Select your default end time';
$lang['l_select_timeformat']= 'Select your default time format (AM/PM)';
$lang['l_select_day']		= 'Select your default start day of week';
$lang['l_select_style']		= 'Select your default style';
$lang['l_set_prefs']		= 'Set preferences';
$lang['l_completed_date']	= 'Completed on';
$lang['l_completed']		= 'Completed';
$lang['l_created']			= 'Created';
$lang['l_due']				= 'Due';
$lang['l_priority']			= 'Priority';
$lang['l_priority_high']	= 'High';
$lang['l_priority_low']		= 'Low';
$lang['l_priority_medium']	= 'Medium';
$lang['l_priority_none']	= 'None';
$lang['l_status']			= 'Status';
$lang['l_status_confirmed'] = 'CONFIRMED' ; 
$lang['l_status_cancelled'] = 'CANCELLED'; 
$lang['l_status_tentative'] = 'TENTATIVE'; 
$lang['l_todo']				= 'To do items';
$lang['l_unfinished']		= 'Unfinished';
$lang['l_prefs_set'] 		= 'Your preferences have been set.';
$lang['l_prefs_unset'] 		= 'Preferences unset. Changes will take place next page load.';
$lang['l_unset_prefs'] 		= 'Unset preferences';
$lang['l_organizer']		= 'Organizer';
$lang['l_attendee']			= 'Attendee';
$lang['l_location']			= 'Location';
$lang['l_download_event']	= 'Download event';
$lang['l_url']   			= 'URL';
$lang['l_admin_header']		= 'PHP iCalendar Administration';
$lang['l_username']			= 'Username';
$lang['l_password']			= 'Password';
$lang['l_login']			= 'Login';
$lang['l_invalid_login']	= 'Wrong username or password.';
$lang['l_addupdate_cal']	= 'Add or Update a Calendar';
$lang['l_addupdate_desc']	= 'Add a calendar by uploading a new file. Update a calendar by uploading a file of the same name.';
$lang['l_delete_cal']		= 'Delete a Calendar';
$lang['l_logout']			= 'Logout';
$lang['l_cal_file']			= 'Calendar File';
$lang['l_php_error']		= 'PHP Error';
$upload_error_gen_lang		= 'There was a problem with your upload.';
$upload_error_lang[0]		= 'There was a problem with your upload.';
$upload_error_lang[1]		= 'The file you are trying to upload is too big.';
$upload_error_lang[2]		= 'The file you are trying to upload is too big.';
$upload_error_lang[3]		= 'The file you are trying upload was only partially uploaded.';
$upload_error_lang[4]		= 'You must select a file for upload.';
$lang['l_upload_error_type'] = 'Only .ics files may be uploaded.';
$lang['l_copy_error']			= 'Failed to copy file';
$lang['l_delete_error']			= 'Failed to delete file';
$lang['l_delete_success']		= 'was deleted successfully.';
$lang['l_action_success']		= 'Your action was successful.';
$lang['l_submit']				= 'Submit';
$lang['l_delete']				= 'Delete';
$all_cal_comb_lang			= 'All Combined';

// New for 2.0
$lang['l_legend']			= 'Legend';
$lang['l_admin_subhead']	= 'Manage your calendars from this page';
$lang['l_prefs_subhead']	= 'Sets a cookie for visiting this site';
$lang['l_rss_info']			= 'RSS Information';
$lang['l_rss_subhead']		= 'Basic RSS feeds available for each calendar';
$lang['l_rss_notenabled']	= 'RSS is not enabled on this site';

// - navigation
$lang['l_back'] 		= 'Back';
$lang['l_next'] 		= 'Next';
$lang['l_prev'] 		= 'Prev';
$lang['l_day_view'] 	= 'Day View';
$lang['l_week_view'] 	= 'Week View';
$lang['l_month_view'] 	= 'Month View';
$lang['l_year_view'] 	= 'Year View';

// ---------------------------------


// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';								// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('year','years');		// for these, put singular
$format_recur_lang['monthly']		= array('month','months');		// and plural forms
$format_recur_lang['weekly']		= array('week','weeks');		// these will be %freq%
$format_recur_lang['daily']			= array('day','days');			// in the replacement below
$format_recur_lang['hourly']		= array('hour','hours');
$format_recur_lang['minutely']		= array('minute','minutes');
$format_recur_lang['secondly']		= array('second','seconds');

$format_recur_lang['start']			= 'Every %int% %freq% %for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']			= 'until %date%';				// ie, 'until January 4'
$format_recur_lang['count']			= 'for a count of %int%';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= 'In months: %list%';			// ie, 'In months: January, February, March'
$format_recur_lang['bymonthday']	= 'On dates: %list%';			// ie, 'On dates: 1, 2, 3, 4'
$format_recur_lang['byday']			= 'On days: %list%';			// ie, 'On days: Mon, Tues, Wed, Thurs'

// ---------------------------------

$daysofweek_lang			= array ('Sunday','Monday','Tuesday','Wednesday','Thursday','Friday','Saturday');
$daysofweekshort_lang		= array ('Sun','Mon','Tue','Wed','Thu','Fri','Sat');
$daysofweekreallyshort_lang	= array ('S','M','T','W','T','F','S');
$monthsofyear_lang			= array ('January','February','March','April','May','June','July','August','September','October','November','December');
$monthsofyearshort_lang		= array ('Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec');

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
$timeFormat = 'g:i A';
$timeFormat_small = 'g:i';

// For date formatting, see note below
$dateFormat_day = '%A, %B %e';
$dateFormat_week = '%B %e';
$dateFormat_week_list = '%a, %b %e';
$dateFormat_week_jump = '%b %e';
$dateFormat_month = '%B %Y';
$dateFormat_month_list = '%A, %B %e';
$dateFormat_year = '%Y';


/*
Notes about dateFormat_*
	The pieces are similar to that of the PHP function strftime(), 
	however only the following is supported at this time:
	
	%A - the full week day name as specified in $daysofweek_lang
	%a - the shortened week day name as specified in $daysofweekshort_lang
	%B - the full month name as specified in $monthsofyear_lang
	%b - the shortened month name as specified in $monthsofyearshort_lang
	%e - the day of the month as a decimal number (1 to 31)
	%Y - the 4-digit year

	If this causes problems with representing your language accurately, let
	us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] 			= 'Error!';
$lang['l_error_window'] 		= 'There was an error!';
$lang['l_error_calendar'] 		= 'The calendar "%s" was being processed when this error occurred.';
$lang['l_error_path'] 			= 'Unable to open the path: "%s"';
$lang['l_error_back'] 			= 'Please use the "Back" button to return.';
$lang['l_error_remotecal'] 		= 'This server blocks remote calendars which have not been approved.';
$lang['l_error_restrictedcal'] 	= 'You have tried to access a calendar that is restricted on this server.';
$lang['l_error_invalidcal'] 	= 'Invalid calendar file. Please try a different calendar.';
$lang['l_error_cantopen'] 		= 'Unable to open calendar.';
$lang['l_error_cache']			= 'Unable to write to cache directory. Please check your config.';
$lang['l_prefs_off']			= 'Preferences are disabled on this installation.';

?>
